pub struct TestRealm { /* private fields */ }Expand description
Runtime harness wrapper providing helper operations for test realms.
Implementations
Sourceimpl TestRealm
impl TestRealm
Sourcepub async fn create(overrides: Vec<ConfigOverride>) -> Result<Self, Error>
pub async fn create(overrides: Vec<ConfigOverride>) -> Result<Self, Error>
Constructs a new TestRealm using a newly created realm factory instance.
Sourcepub async fn connect_to_protocol<P: DiscoverableProtocolMarker>(
&self,
) -> Result<P::Proxy, Error>
pub async fn connect_to_protocol<P: DiscoverableProtocolMarker>( &self, ) -> Result<P::Proxy, Error>
Connects to a FIDL protocol exposed by the component under test in the test realm.
Sourcepub fn get_control<M: MockControlMarker>(
&self,
) -> Result<M::ControlProxy, Error>
pub fn get_control<M: MockControlMarker>( &self, ) -> Result<M::ControlProxy, Error>
Connects to a mock control proxy.
Sourcepub async fn get_directory(&self, path: &str) -> Result<DirectoryProxy, Error>
pub async fn get_directory(&self, path: &str) -> Result<DirectoryProxy, Error>
Opens an isolated directory at the given path within the exposed directory of the realm.
Sourcepub fn subscribe_to_lifecycle(&self) -> Result<LifecycleStream, Error>
pub fn subscribe_to_lifecycle(&self) -> Result<LifecycleStream, Error>
Subscribes to lifecycle events emitted by the test environment.
Sourcepub fn emit_lifecycle_event(&self, event: LifecycleEvent)
pub fn emit_lifecycle_event(&self, event: LifecycleEvent)
Emits a lifecycle event to all subscribed lifecycle streams.
pub async fn stop_component(&self, name: &str) -> Result<(), Error>
pub async fn is_running(&self, name: &str) -> Result<bool, Error>
pub async fn start_component(&self, name: &str) -> Result<(), Error>