MockControlMarker

Trait MockControlMarker 

pub trait MockControlMarker {
    type ControlProxy;

    // Required method
    fn connect_from_namespace() -> Result<Self::ControlProxy, Error>;
}
Trait implemented by mock control markers to connect to mock control proxies.

Required Associated Types

type ControlProxy

The control proxy type associated with this mock.

Required Methods

fn connect_from_namespace() -> Result<Self::ControlProxy, Error>

Connects to the mock control proxy from the incoming namespace.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors